@@ -2,9 +2,8 @@ package WWW::Contact;
 
 use Class::MOP ();
 use Moose;
-use Moose::Util::TypeConstraints;
 
-our $VERSION   = '0.20';
+our $VERSION   = '0.21';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 has 'errstr'   => ( is => 'rw', isa => 'Maybe[Str]' );
@@ -178,7 +177,6 @@ sub register_supplier {
 }
 
 no Moose;
-no Moose::Util::TypeConstraints;
 
 __PACKAGE__->meta->make_immutable;
 
